@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : libipv6addr.c
- * Version    : $Id: libipv6addr.c,v 1.9 2002/11/04 19:49:45 peter Exp $
+ * Version    : $Id: libipv6addr.c,v 1.12 2003/08/15 11:58:28 peter Exp $
  * Copyright  : 2001-2002 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  *
  * Information:
@@ -410,13 +410,18 @@ int ipv6addr_getregistry(const ipv6calc_ipv6addr *ipv6addrp) {
 		
 		if ( (st & 0xFFFFFE00u) == 0x20010600u ||
 		     (st & 0xFFFFFE00u) == 0x20010800u || 
-		     (st & 0xFFFFFE00u) == 0x20010A00u )  {
+		     (st & 0xFFFFFE00u) == 0x20010A00u ) {
 			/* 2001:0600::/23 -> RIPE NCC */
 			/* 2001:0800::/23 -> RIPE NCC */
 			/* 2001:0A00::/23 -> RIPE NCC */
 			return(IPV6_ADDR_REGISTRY_RIPE);
 		};
 
+		if ( (st & 0xFFFFFE00u) == 0x20011200u ) {
+			/* 2001:1200::/23 -> LACNIC */
+			return(IPV6_ADDR_REGISTRY_LACNIC);
+		};
+
 		return (IPV6_ADDR_REGISTRY_RESERVED);
 	};
 
@@ -1048,3 +1053,28 @@ int libipv6addr_ipv6addrstruct_to_tokenlsb64(const ipv6calc_ipv6addr *ipv6addrp,
 	return (retval);
 };
 #undef DEBUG_function_name
+
+/*
+ * function prints an IPv6 address in native octal format
+ *
+ * in:  ipv6addr = IPv6 address structure
+ * formatoptions
+ * out: *resultstring = IPv6 address (modified)
+ * ret: ==0: ok, !=0: error
+ */
+#define DEBUG_function_name "libipv6addr/ipv6addrstruct_to_octal"
+int libipv6addr_to_octal(const ipv6calc_ipv6addr *ipv6addrp, char *resultstring, const uint32_t formatoptions) {
+	int retval = 1;
+	char tempstring[NI_MAXHOST];
+
+	if ( (formatoptions & FORMATOPTION_printfulluncompressed) != 0 ) {
+		snprintf(tempstring, sizeof(tempstring), "\\%03o\\%03o\\%03o\\%03o\\%03o\\%03o\\%03o\\%03o\\%03o\\%03o\\%03o\\%03o\\%03o\\%03o\\%03o\\%03o", ipv6addrp->in6_addr.s6_addr[0], ipv6addrp->in6_addr.s6_addr[1], ipv6addrp->in6_addr.s6_addr[2], ipv6addrp->in6_addr.s6_addr[3], ipv6addrp->in6_addr.s6_addr[4], ipv6addrp->in6_addr.s6_addr[5], ipv6addrp->in6_addr.s6_addr[6], ipv6addrp->in6_addr.s6_addr[7], ipv6addrp->in6_addr.s6_addr[8], ipv6addrp->in6_addr.s6_addr[9], ipv6addrp->in6_addr.s6_addr[10], ipv6addrp->in6_addr.s6_addr[11], ipv6addrp->in6_addr.s6_addr[12], ipv6addrp->in6_addr.s6_addr[13], ipv6addrp->in6_addr.s6_addr[14], ipv6addrp->in6_addr.s6_addr[15]);
+	} else {
+		snprintf(tempstring, sizeof(tempstring), "\\%o\\%o\\%o\\%o\\%o\\%o\\%o\\%o\\%o\\%o\\%o\\%o\\%o\\%o\\%o\\%o", ipv6addrp->in6_addr.s6_addr[0], ipv6addrp->in6_addr.s6_addr[1], ipv6addrp->in6_addr.s6_addr[2], ipv6addrp->in6_addr.s6_addr[3], ipv6addrp->in6_addr.s6_addr[4], ipv6addrp->in6_addr.s6_addr[5], ipv6addrp->in6_addr.s6_addr[6], ipv6addrp->in6_addr.s6_addr[7], ipv6addrp->in6_addr.s6_addr[8], ipv6addrp->in6_addr.s6_addr[9], ipv6addrp->in6_addr.s6_addr[10], ipv6addrp->in6_addr.s6_addr[11], ipv6addrp->in6_addr.s6_addr[12], ipv6addrp->in6_addr.s6_addr[13], ipv6addrp->in6_addr.s6_addr[14], ipv6addrp->in6_addr.s6_addr[15]);
+	};
+
+	snprintf(resultstring, NI_MAXHOST, "%s", tempstring);
+	retval = 0;	
+	return (retval);
+};
+#undef DEBUG_function_name
