@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : libmac.c
- * Version    : $Id: libmac.c,v 1.6 2002/08/30 20:43:57 peter Exp $
+ * Version    : $Id: libmac.c,v 1.7 2003/02/02 16:41:42 peter Exp $
  * Copyright  : 2001-2002 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -14,7 +14,7 @@
 #include "libipv6calc.h"
 #include "libmac.h"
 
-static char ChSet[] = "0123456789abcdefABCDEF:-";
+static char ChSet[] = "0123456789abcdefABCDEF:- ";
 
 /* function 48-bit MAC address to MACaddr_structure
  *
@@ -24,7 +24,7 @@ static char ChSet[] = "0123456789abcdefABCDEF:-";
  */
 #define DEBUG_function_name "libmac/mac_to_macaddrstruct"
 int mac_to_macaddrstruct(char *addrstring, char *resultstring, ipv6calc_macaddr *macaddrp) {
-	int retval = 1, result, i, ccolons = 0, cdashes = 0;
+	int retval = 1, result, i, ccolons = 0, cdashes = 0, cspaces = 0;
 	size_t cnt;
 	int temp[6];
 
@@ -35,7 +35,7 @@ int mac_to_macaddrstruct(char *addrstring, char *resultstring, ipv6calc_macaddr
 		return (retval);
 	};
 
-	/* check for hex chars and ":"/"-" only content */
+	/* check for hex chars and ":"/"-"/" " only content */
 	cnt = strspn(addrstring, ChSet);
 	if ( cnt < strlen(addrstring) ) {
 		snprintf(resultstring, NI_MAXHOST, "Illegal character in given MAC address '%s' on position %d (%c)!", addrstring, (int) cnt+1, addrstring[cnt]);
@@ -44,16 +44,18 @@ int mac_to_macaddrstruct(char *addrstring, char *resultstring, ipv6calc_macaddr
 		
 	};
 
-	/* count ":", must be 5 */
+	/* count ":" or "-" or " " must be 5 */
 	for (i = 0; i < (int) strlen(addrstring); i++) {
 		if (addrstring[i] == ':') {
 			ccolons++;
 		} else if (addrstring[i] == '-') {
 			cdashes++;
+		} else if (addrstring[i] == ' ') {
+			cspaces++;
 		};
 	};
 
-	if ( ! ( ( ccolons == 5 && cdashes == 0) || ( ccolons == 0 && cdashes == 5) ) ) {
+	if ( ! ( ( ccolons == 5 && cdashes == 0 && cspaces == 0) || ( ccolons == 0 && cdashes == 5 && cspaces == 0)  || ( ccolons == 0 && cdashes == 0 && cspaces == 5)) ) {
 		snprintf(resultstring, NI_MAXHOST, "Error, given MAC address '%s' is not valid (number of colons/dashes is not 5)!", addrstring);
 		retval = 1;
 		return (retval);
@@ -64,6 +66,8 @@ int mac_to_macaddrstruct(char *addrstring, char *resultstring, ipv6calc_macaddr
 		result = sscanf(addrstring, "%x:%x:%x:%x:%x:%x", &temp[0], &temp[1], &temp[2], &temp[3], &temp[4], &temp[5]);
 	} else if ( cdashes == 5 ) {
 		result = sscanf(addrstring, "%x-%x-%x-%x-%x-%x", &temp[0], &temp[1], &temp[2], &temp[3], &temp[4], &temp[5]);
+	} else if ( cspaces == 5 ) {
+		result = sscanf(addrstring, "%x %x %x %x %x %x", &temp[0], &temp[1], &temp[2], &temp[3], &temp[4], &temp[5]);
 	} else {
 		snprintf(resultstring, NI_MAXHOST, "Error, unexpected failure on scanning MAC address '%s'!", addrstring);
 		retval = 1;
